var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React from 'react';
import styled from 'styled-components';
import defaultTheme from '../../../theme';
import { Header, Text } from '../../elements/Text';
/**
 * MessageHeader
 */
var MessageHeader = styled(Header)({
    paddingBottom: '0.25rem',
});
/**
 * MessageContent
 */
var MessageContent = styled(Text)({
    margin: 0,
});
var StyledDiv = styled.div({
    position: 'relative',
    minHeight: '1em',
    margin: '1em',
    padding: '1em 1.5em',
    lineHeight: '1.5em',
}, 
// Handle message colours
function (_a) {
    var theme = _a.theme, info = _a.info, success = _a.success, negative = _a.negative, floating = _a.floating;
    var color = info
        ? 'blue'
        : success
            ? 'green'
            : negative
                ? 'red'
                : 'primaryText';
    var backgroundColor = info || success || negative
        ? theme.colors[color].verylight
        : theme.greyscale.lighter;
    var borderColour = info || success || negative
        ? theme.colors[color].default
        : theme.greyscale.dark;
    var boxShadow = floating
        ? "0 0 0 1px  " + borderColour + " inset, 0 2px 4px 0  " + theme.greyscale.medium + ", 0 2px 10px 0  " + theme.greyscale.medium
        : "0 0 0 1px " + borderColour + " inset";
    return {
        color: theme.colors[color].default,
        borderRadius: theme.sizes.borderRadius,
        backgroundColor: backgroundColor,
        boxShadow: boxShadow,
        '& > .icon': {
            fill: theme.colors[color].default,
        },
    };
}, 
// Handle icon
function (_a) {
    var icon = _a.icon;
    return icon
        ? {
            display: 'flex',
            alignItems: 'center',
            '& > .content': {
                display: 'block',
                flex: '1 1 auto',
                verticalAlign: 'middle',
            },
            '& > .icon': {
                display: 'block',
                flex: '0 0 auto',
                opacity: 0.8,
                marginRight: '0.6em',
            },
        }
        : null;
});
StyledDiv.defaultProps = {
    theme: defaultTheme,
};
/**
 * Bar for showing feedback such as error or success messages
 */
export var Message = function (props) {
    var header = props.header, content = props.content, Icon = props.icon;
    var headerNode = header && React.createElement(MessageHeader, null, header);
    var contentNode = content && React.createElement(MessageContent, null, content);
    if (Icon) {
        return (React.createElement(StyledDiv, __assign({}, props),
            Icon && React.createElement(Icon, { className: "icon", width: 30, height: 30 }),
            React.createElement("div", { className: "content" },
                headerNode,
                contentNode)));
    }
    return (React.createElement(StyledDiv, __assign({}, props),
        headerNode,
        contentNode));
};
