import { OGIT } from '@hiro-graph/client';
import { ColorDefinitionValuesEnum, HiroColors, HiroPartialTheme } from '../../types';
export declare type Widgets = 'WelcomeConversion' | 'WelcomeTeaching' | 'SessionList' | 'Demo' | 'TopTeachingContributors' | 'TopConverters' | 'Statistic';
export declare type ButtonType = 'primary' | 'secondary';
export declare type DataTimeseriesName = 'TotalKIs' | 'AutomatedTasks' | 'TopContributors' | 'AutomationRate';
export interface CircleColor {
    color: HiroColors;
    greyScale: ColorDefinitionValuesEnum;
}
export interface StatisticData {
    title: string;
    differenceText: string;
    whatItIs: string;
    howToImprove: string;
    angle: number;
    valueText: string;
    valueColor: CircleColor;
    backgroundColor: CircleColor;
    error: boolean;
    errorText: string;
}
export interface Contributors {
    [key: string]: number;
}
/**
 * Basic Widget config
 */
export interface BaseWidgetConfig {
    size?: string | number;
    title?: string;
    as: Widgets;
}
/**
 * Advanced Widget config with automatic data loading
 */
export interface Me {
    id: string;
    accountId: string;
    email: string;
    displayName: string;
    roles: string[];
}
export interface WidgetProvider {
    openApp: (appId: string, options: any) => void;
    selectMe: () => Me;
    selectAppsIds: () => {
        [key: string]: string;
    };
    getEnvUrls: () => {
        [key: string]: string;
    };
}
export interface DashboardConfig {
    theme: HiroPartialTheme;
    widgets: Record<string, WidgetConfig>;
}
/**
 * Widgets
 */
export interface WelcomeConversionWidgetConfig extends BaseWidgetConfig {
    as: 'WelcomeConversion';
}
export interface WelcomeTeachingWidgetConfig extends BaseWidgetConfig {
    as: 'WelcomeTeaching';
}
export interface SessionListWidgetConfig extends BaseWidgetConfig {
    as: 'SessionList';
}
export interface DemoWidgetConfig extends BaseWidgetConfig {
    as: 'Demo';
}
export interface TopContributorsWidgetConfig extends BaseWidgetConfig {
    as: 'TopTeachingContributors';
}
export interface TopConvertersWidgetConfig extends BaseWidgetConfig {
    as: 'TopConverters';
}
export interface StatisticWidgetConfig extends BaseWidgetConfig {
    as: 'Statistic';
}
export declare type WidgetConfig = WelcomeConversionWidgetConfig | WelcomeTeachingWidgetConfig | SessionListWidgetConfig | DemoWidgetConfig | TopContributorsWidgetConfig | TopConvertersWidgetConfig | StatisticWidgetConfig;
export interface WidgetProps {
    as: Widgets;
}
export interface OgitSession extends OGIT.SafeNode {
    'ogit/title'?: string;
    '/teaching_issue_subject'?: string;
    '/teaching_step_progress'?: string;
    '/teaching_ki_progress'?: string;
    '/teaching_ownerId'?: string;
    '/teaching_conversion_ownerId'?: string;
    '/teaching_is_handedover'?: string;
    '/teaching_rooms'?: string;
    '/teaching_rooms_completed'?: string;
    '/teaching_steps'?: string;
    '/teaching_steps_deployed'?: string;
    'ogit/Knowledge/archived': string;
}
/**
 * Teaching Sessions Widget
 */
export interface SessionItemProps {
    session: OgitSession;
}
export interface ProgressBarProps {
    progress: number;
}
export interface ProgressBarChunkProps extends ProgressBarProps {
    active?: boolean;
}
export interface DetailsContainerItem {
    name: string;
    content: string;
}
/**
 * Top Contributors Widget
 */
export interface ContributorProps {
    userId: string;
    ranking: number;
    count: number;
    avatarUrl: string;
}
export declare type ContributorColumns = Array<ContributorProps[]>;
export declare type ContributorStats = [string, number];
